#
# spec file for package inotify-tools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           inotify-tools
Version:        4.23.9.0
Release:        1.4
Summary:        Tools for inotify
License:        GPL-2.0-only WITH Linux-syscall-note AND GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://github.com/inotify-tools/inotify-tools
Source:         https://github.com/inotify-tools/inotify-tools/archive/%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  libtool

%description
inotify is a kernel facility to watch file system changes. This
package provides some tools for it.

%package -n libinotifytools0
Summary:        Library files for inotify-tools
Group:          System/Monitoring

%description -n libinotifytools0
inotify is a kernel facility to watch file system changes. This
package provides some tools for it.

%package devel
Summary:        Development files for inotify-tools
Group:          Development/Tools/Other
Requires:       libinotifytools0 = %{version}

%description devel
This package contains the development files for inotify-tools, which provides
utilities for the kernel facility inotify.

%package doc
Summary:        Documentation for inotify-tools
Group:          Documentation/Other
Requires:       %{name} = %{version}
BuildArch:      noarch

%description doc
This package contains the documentation for inotify-tools, which provides
utilities for the kernel facility inotify.

%prep
%autosetup -p1

%build
./autogen.sh
%configure --disable-static \
    --docdir=%{_docdir}/%{name} \
    --enable-doxygen
%make_build

%install
%make_install
%fdupes %{buildroot}/%{_docdir}
rm %{buildroot}/%{_libdir}/libinotifytools.la

%post -n libinotifytools0 -p /sbin/ldconfig
%postun -n libinotifytools0 -p /sbin/ldconfig

%check
%make_build check

%files
%license COPYING
%{_bindir}/*
%{_mandir}/man1/*.1%{?ext_man}

%files -n libinotifytools0
%license COPYING
%{_libdir}/libinotifytools.so.*

%files devel
%license COPYING
%{_libdir}/libinotifytools.so
%{_includedir}/inotifytools/

%files doc
%license COPYING
%doc %{_docdir}/%{name}

%changelog
* Sat Dec 30 2023 Dirk Müller <dmueller@suse.com>
- update to 4.23.9.0:
  * support cross compile for Android
  * libinotifytools: Rename init variable to fix conflict with
    entry point
  * Add CodeQL workflow for GitHub code scanning
  * Fix build with musl and add Alpine buildnode to CI
  * Update Cirrus CI FreeBSD images
  * Fix enabling of fanotify/fsnotify.
  * Fix fanotify_supported()
  * Combine to one build machine, reduce test iteration to 64
  * Add -fanalyzer to build
  * Enable CentOS Stream 9 build
  * Add debian 12
  * Ensure C++ libraries are not linked in
* Sun Jun 19 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.22.6.0:
  * Cast pointer to char so increments to pointer are at one byte
    intervals
* Sat May  7 2022 Dirk Müller <dmueller@suse.com>
- update to 3.22.1.0:
  * print to stderr if you fail to fopen file
  * Properly terminate escaped CSV strings. (#158)
  * Fix printing of filename when watching a file
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 3.21.9.6 (jsc#SLE-21025):
  * update path for includes in stats.h
  * Fix spellings in manpages
* Mon Sep 27 2021 Dirk Müller <dmueller@suse.com>
- update to 3.21.9.5:
  * Fix Wrong pointer passed to realloc
  * Fix offset compiler warning
  * various static code analyse annotations and fixes
* Sun Dec 20 2020 Dirk Müller <dmueller@suse.com>
- update to 3.20.11.0:
  * Added --no-dereference to watch a symlink
  * bugfixes
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.20.2:
  * New maintainer
  * Fix potential buffer overflow
  * gcc 9 support
- remove inotify-tools-no-timestamp-in-doc.patch
  inotify-return.patch (merged upstream)
* Thu Apr  4 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Update inotify-tools-no-timestamp-in-doc.patch
  because doxygen footers are no more an issue and man page
  date needs to be normalized (boo#1047218)
* Sun Feb  3 2019 Dirk Mueller <dmueller@suse.com>
- adjust source to the github download url
* Fri Aug 31 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.20.1
  * no changelog
  * drop upstreamed patch reserved-identifier.patch
* Mon Oct 19 2015 schwab@suse.de
- reserved-identifier.patch: fix invalid use of reserved identifier
* Fri Mar 20 2015 jweberhofer@weberhofer.at
- Do not longer provide lib%%{name}
- Package COPYING
* Wed Mar 18 2015 jweberhofer@weberhofer.at
- Build noarch package for doc only for newer suse version, otherwise
  build fails.
* Wed Mar 18 2015 jweberhofer@weberhofer.at
- Added inotify-tools-no-timestamp-in-doc.patch to remove date and time
  from the doxygen-generated documentation files.
* Fri Mar  6 2015 jweberhofer@weberhofer.at
- Splitted off the shared library
* Thu Feb 26 2015 jweberhofer@weberhofer.at
- Updated download location
* Mon Sep  9 2013 stephan.barth@suse.com
- removed %%clean section
- enabled doxygen in configure and split up doc package
- added fdupes call for doc (doxygen) files
- added %%check section with simple "make check"
- moved .so files to the main package
- added --disable-static to configure and remove .la file
- replaced RPM_BUILD_ROOT with %%buildroot
* Mon Sep  2 2013 stephan.barth@suse.com
- some spec file clean up:
  - explicitly list file names
  - removed unneeded BuildRequires and %%changelog for the -devel
    sub-package
  - removed pointless %%lang_package tag
  - specified upstream download URI in the URL tag
- inotify-return.patch:
  specifies a return value for a function to fix a build error
  (no-return-in-nonvoid-function)
* Tue Aug 27 2013 stephan.barth@suse.com
- initial package
